# Sous-Chef

Sous-Chef is a web application to **help** organizations to **plan** and **deliver** meals, and to manage clients files.

## Installation

- For production installation, please refer to the [installation procedure](INSTALL.md).
- For developer setup, refer to [DEVSETUP.md](DEVSETUP.md).

## Communication

Please join `#souschef` on *irc.freenode.net*.

A public mailing list was available in the past but is now inactive. You may [browse the archives here](https://lists.savoirfairelinux.net/pipermail/sous-chef/).

## How to contribute

Please refer to the [contribution guidelines](https://github.com/savoirfairelinux/sous-chef/blob/dev/CONTRIBUTING.md).

## Licensing

Sous-Chef is an open-source software published under the GNU AFFERO GENERAL PUBLIC licence, version 3.

## Talks at conferences

- [Sous-Chef : Free software for the meals-on-wheels communities - DebConf17 in Montreal](docs/meetup/DebConf17_SousChef_Talk_20170805.pdf)

## Resources

Some useful resources:

* [Semantic UI](http://semantic-ui.com)

## About the Santropol Roulant

[Santropol Roulant](https://santropolroulant.org/) is an intergenerational community food hub where we grow, prepare and deliver food. In doing so, we create a continuum of engaging services that help build a stronger social fabric, and increase food security and social inclusion for Montrealers.
